"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @author Olsi Rrjolli
 * These Repository represent the abstract layer for the book store database
 */
const AWS = require("aws-sdk");
const typescript_ioc_1 = require("typescript-ioc");
const restified_aws_lambda_1 = require("restified-aws-lambda");
class BookStoreRepository {
    constructor() {
        AWS.config.update({
            region: process.env.awsRegion
        });
        this.params = {
            TableName: process.env.bookStoreTableName
        };
    }
    getBookStores() {
        this.params.FilterExpression = 'isDeleted = :isDeleted';
        this.params.ExpressionAttributeValues = {
            ':isDeleted': false
        };
        return this.dynamoDbClient.scan(this.params).promise().then((result) => {
            return result.Items;
        });
    }
    createBookStore(bookStore) {
        this.params.Item = bookStore;
        return this.dynamoDbClient.put(this.params).promise().then((result) => {
            return { id: bookStore.id };
        });
    }
    getBookStoreById(id) {
        this.params.Key = {
            id: id
        };
        return this.dynamoDbClient.get(this.params).promise().then((result) => {
            if (Object.keys(result).length === 0) {
                throw new restified_aws_lambda_1.default(`Can not found book store ${id}`);
            }
            return result.Item;
        });
    }
    updateBookStore(bookStore, id) {
        this.params.Item = bookStore;
        this.params.ConditionExpression = 'contains(id, :id)';
        this.params.ExpressionAttributeValues = {
            ':id': id
        };
        return this.dynamoDbClient.put(this.params).promise().then((result) => {
            return result;
        }).catch((err) => {
            if (err.name === 'ConditionalCheckFailedException') {
                console.trace(err);
                throw new restified_aws_lambda_1.default(`Can not found book store ${id}`);
            }
            return Promise.reject(err);
        });
    }
    deleteBookStore(id) {
        this.params.UpdateExpression = 'set isDeleted = :isDeleted';
        this.params.ConditionExpression = 'contains(id, :id)';
        this.params.ExpressionAttributeValues = {
            ':isDeleted': true,
            ':id': id
        };
        this.params.Key = {
            id: id
        };
        return this.dynamoDbClient.update(this.params).promise().then((result) => {
            return result;
        }).catch((err) => {
            if (err.name === 'ConditionalCheckFailedException') {
                console.trace(err);
                throw new restified_aws_lambda_1.default(`Can not found book store ${id}`);
            }
            return Promise.reject(err);
        });
    }
}
__decorate([
    typescript_ioc_1.Inject,
    __metadata("design:type", AWS.DynamoDB.DocumentClient)
], BookStoreRepository.prototype, "dynamoDbClient", void 0);
exports.default = BookStoreRepository;
//# sourceMappingURL=BookStoreRepository.js.map